/*
 * $Id: PDFOverlay.java 3373 2008-05-12 16:21:24Z xlv $
 *
 * This code is part of the 'iText Tutorial'.
 * You can find the complete tutorial at the following address:
 * http://itextdocs.lowagie.com/tutorial/
 *
 * This code is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 *
 * itext-questions@lists.sourceforge.net
 */
import java.io.FileOutputStream;
import java.util.ArrayList;

import com.lowagie.text.Document;
import com.lowagie.text.Rectangle;
import com.lowagie.text.pdf.BaseFont;
import com.lowagie.text.pdf.PdfContentByte;
import com.lowagie.text.pdf.PdfImportedPage;
import com.lowagie.text.pdf.PdfReader;
import com.lowagie.text.pdf.PdfWriter;
import com.lowagie.text.pdf.PdfStamper;

/**
 * Reads the pages of two PDF files and merges them into a single 
 * PDF file by overlaying them page by page.  The number of pages
 * and page size must the be same in both files.
 */
public class PDFOverlay {
    /**
     * Reads the pages of two PDF files and merges them into a single 
     * PDF file by overlaying them page by page.  The number of pages and
     * page size must be the same in both files.
     * @param args <infile1> <infile2> <outfile>
     */
    public static void main(String[] args) {
	String usage = "Usage: PDFOverlay <infile1> <infile2> <outfile>";
        if (args.length != 3) {
	    System.err.println(usage);
	    System.exit(-1);
	}
        String fn1 = args[0];
	String fn2 = args[1];
        String ofn = args[2];
        try {
            // create readers for the input documents
            PdfReader reader1 = new PdfReader(fn1);
            reader1.consolidateNamedDestinations();
            PdfReader reader2 = new PdfReader(fn2);
            reader2.consolidateNamedDestinations();

            // retrieve the total number of pages
            int n = reader1.getNumberOfPages();
            int n2 = reader2.getNumberOfPages();
            if (n != n2) {
		System.err.println("ERROR: Files have different numbers of pages: "
				   + n + " versus " + n2);
		System.exit(-1);
            }

            // retrieve the size of the first page
            Rectangle psize1 = reader1.getPageSize(1);
            float width = psize1.getHeight();
            float height = psize1.getWidth();
            Rectangle psize2 = reader2.getPageSize(1);
            float width2 = psize2.getHeight();
            float height2 = psize2.getWidth();
            if (width != width2 || height != height2) {
		System.err.println("ERROR: Page dimensions don't match: "
				   + width + "x" + height + "versus"
				   + width2 + "x" + height2); 
		System.exit(-1);
            }
            
            // create a stamper with the first argument as a primary
            // document and use it to add content to each page
            PdfStamper st = new PdfStamper(reader1, new FileOutputStream(ofn));
            for (int i = 1; i <= n; i++) {
                PdfImportedPage page = st.getImportedPage(reader2, i);
                PdfContentByte over = st.getOverContent(i);
                over.addTemplate(page, 1.0f, 0, 0, 1.0f, 0, 0);
	    }
            st.close();
        }
        catch (Exception de) {
            //de.printStackTrace();
            System.err.println("ERROR: An error occurred. The error message was");
            System.err.println("  \"" + de.getMessage() + "\"");
            System.exit(-1);
        }
        System.exit(0);
    }
}
